==> v8.3.zip: ru_twords_ru_tw/bible/other/wisemen.md <==
# мудрец, волхв

## Определение:

Мудрецом в Библии обычно называли умного, образованного человека, уравновешенного и здравого в своих поступках, а также такого человека, который обладал обширным образованием и большими способностями. Как правило, такие люди служили своим правителям.

* В Библи часто описываются люди, которые становились мудрыми благодаря своему послушанию Богу.
* Мудрецами в Библии назывались учёные, астрологи, толкователи снов, а также люди, занимающиеся оккультизмом. Такие люди обычно служили фараонам и языческим царям. Например, царь Навуходоносор приказал мудрецам объяснить значение его снов, но никто из них не смог этого сделать, кроме Даниила, получившего истолкование непосредственно от Бога.
* Мудрецы могли заниматься магией и гаданиями. Зачастую они творили чудеса с помощью злых духов. К мудрецам, служащим фараону и языческим царям, относились тайноведцы, гадатели, чародеи, волшебники и халдеи.
* В Новом Завете мудрецы, пришедшие с востока для того, чтобы поклониться младенцу Иисусу, названы “волхвами”. Возможно, это были учёные, служившие какому-то восточному правителю. Вероятно, они могли быть астрологами, изучавшими звёзды. Существует предположение, что они могли быть потомками тех мудрецов, которых пророк Даниил учил в Вавилоне.
* В зависимости от контекста слово “мудрец” может быть переведено как “одарённый человек”, “образованный человек”, “умный человек”.

(См. также: [Вавилон](../names/babylon.md), [Даниил](../names/daniel.md), [гадание](../other/divination.md), [магия](../other/magic.md), [Навуходоносор](../names/nebuchadnezzar.md), [правитель](../other/ruler.md), [мудрый](../kt/wise.md))

## Ссылки на библейский текст:

* [1 Пар. 27:32-34](rc://*/tn/help/1ch/27/32)
* [Дан. 2:1-2](rc://*/tn/help/dan/02/01)
* [Дан. 2:10-11](rc://*/tn/help/dan/02/10)

## Данные о слове:

* Номера Стронга: H2445, H2450, H3778, H3779, G4680

==> v9.2.zip: ru_twords_ru_tw/bible/other/wisemen.md <==
# мудрец, волхв

## Определение:

Мудрецом в Библии обычно называли умного, образованного человека, уравновешенного и здравого в своих поступках, а также такого человека, который обладал обширным образованием и большими способностями. Как правило, такие люди служили своим правителям.
* В Библи часто описываются люди, которые становились мудрыми благодаря своему послушанию Богу. 
* Мудрецами в Библии назывались учёные, астрологи, толкователи снов, а также люди, занимающиеся оккультизмом. Такие люди обычно служили фараонам и языческим царям. Например, царь Навуходоносор приказал мудрецам объяснить значение его снов, но никто из них не смог этого сделать, кроме Даниила, получившего истолкование непосредственно от Бога.
* Мудрецы могли заниматься магией и гаданиями. Зачастую они творили чудеса с помощью злых духов. К мудрецам, служащим фараону и языческим царям, относились тайноведцы, гадатели, чародеи, волшебники и халдеи.
* В Новом Завете мудрецы, пришедшие с востока для того, чтобы поклониться младенцу Иисусу, названы “волхвами”. Возможно, это были учёные, служившие какому-то восточному правителю. Вероятно, они могли быть астрологами, изучавшими звёзды. Существует предположение, что они могли быть потомками тех мудрецов, которых пророк Даниил учил в Вавилоне.
* В зависимости от контекста слово “мудрец” может быть переведено как “одарённый человек”, “образованный человек”, “умный человек”.

(См. также: [Вавилон](../names/babylon.md), [Даниил](../names/daniel.md), [гадание](../other/divination.md), [магия](../other/magic.md), [Навуходоносор](../names/nebuchadnezzar.md), [правитель](../other/ruler.md), [мудрый](../kt/wise.md))

## Ссылки на библейский текст:

* [1 Пар. 27:32-34](rc://ru/tn/help/1ch/27/32)
* [Дан. 2:1-2](rc://ru/tn/help/dan/02/01)
* [Дан. 2:10-11](rc://ru/tn/help/dan/02/10)

## Данные о слове:

* Номера Стронга: H2445, H2450, H3778, H3779, G4680
